@@ -21,9 +21,21 @@
 #ifdef HAVE_UTIME_H
 # include <utime.h>
 #endif /* HAVE_UTIME_H */
-#if defined TM_IN_SYS_TIME && defined HAVE_SYS_TIME
+#if defined (TM_IN_SYS_TIME) && defined (HAVE_SYS_TIME)
 # include <sys/time.h>
-#endif /* defined TM_IN_SYS_TIME && defined HAVE_SYS_TIME */
+#endif /* defined (TM_IN_SYS_TIME) && defined (HAVE_SYS_TIME) */
+
+
+struct _FileIO
+{
+#ifdef G_OS_WIN32
+  HANDLE hFile;
+#else /* not G_OS_WIN32 */
+  int fd;
+  gchar *file;
+  guint share;
+#endif /* not G_OS_WIN32 */
+};
 
 
 /******************************************************************************
@@ -1091,10 +1103,10 @@ fileio_settime (const gchar *file,
 {
 #ifdef G_OS_WIN32
   HANDLE hFile;
-# if defined UNICODE && ! GLIB_CHECK_VERSION(2,6,0)
+# if defined (UNICODE) && ! GLIB_CHECK_VERSION(2,6,0)
   gchar *utf8file;
   LPTSTR lpszFile;
-# endif /* UNICODE and not GLIB_CHECK_VERSION(2,6,0) */
+# endif /* defined (UNICODE) && ! GLIB_CHECK_VERSION(2,6,0) */
 #else /* not G_OS_WIN32 */
   struct stat sbuf;
   struct utimbuf ubuf;
