@@ -23,17 +23,20 @@
 #include "export.h"
 #include "file.h"
 #include "general.h"
+#include "genre.h"
 #include "mm_dialog.h"
 #include "mm_list.h"
+#include "process.h"
 #include "reload.h"
 #include "root.h"
+#include "version.h"
 #include "misc/fileio.h"
 #include "misc/misc.h"
-#include "misc/misc_charlist.h"
-#include "misc/misc_charset.h"
-#include "misc/misc_conf.h"
-#include "misc/misc_history.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzcharlist.h"
+#include "orz/orzcharset.h"
+#include "orz/orzconf.h"
+#include "orz/orzhistory.h"
+#include "orz/orzmdi.h"
 #ifdef G_OS_WIN32
 # include <gdk/gdkwin32.h>
 #endif /* G_OS_WIN32 */
@@ -45,9 +48,8 @@
 *                                                                             *
 ******************************************************************************/
 void
-command_new (gpointer   callback_data,
-             guint      callback_action,
-             GtkWidget *widget)
+command_new (GtkWidget *widget,
+             gpointer   user_data)
 {
   file_open_edit (NULL);
 }
@@ -69,9 +71,8 @@ command_open_ok (GtkWidget *widget,
 
 
 void
-command_open (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_open (GtkWidget *widget,
+              gpointer   user_data)
 {
   gchar *file = NULL, *path;
   GtkWidget *dialog;
@@ -121,22 +122,20 @@ command_open (gpointer   callback_data,
 
 
 void
-command_close (gpointer   callback_data,
-               guint      callback_action,
-               GtkWidget *widget)
+command_close (GtkWidget *widget,
+               gpointer   user_data)
 {
   gint page;
 
   if ((page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi))) >= 0
-    && prompt_close ((MmaidWindow *)misc_mdi_get_data (MISC_MDI (mdi), page)))
+    && prompt_close ((MmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), page)))
     gtk_notebook_remove_page (GTK_NOTEBOOK (mdi), page);
 }
 
 
 void
-command_save (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_save (GtkWidget *widget,
+              gpointer   user_data)
 {
   gchar *root = NULL, *tmp;
   const gchar *file;
@@ -144,12 +143,12 @@ command_save (gpointer   callback_data,
   MmaidWindow *mmaid;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  mmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
-  file = misc_mdi_get_file (MISC_MDI (mdi), page_num);
+  mmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
+  file = orz_mdi_get_file (ORZ_MDI (mdi), page_num);
   tmp = g_path_get_dirname (file);
   root = g_strconcat (tmp, G_DIR_SEPARATOR_S, NULL);
   g_free (tmp);
-  if (!misc_mdi_get_created (MISC_MDI (mdi), page_num))
+  if (!orz_mdi_get_created (ORZ_MDI (mdi), page_num))
     {
       gchar *path;
       gint leng;
@@ -168,7 +167,7 @@ command_save (gpointer   callback_data,
     }
   if (i >= 0)
     {
-      command_saveas (callback_data, callback_action, widget);
+      command_saveas (widget, user_data);
     }
   else
     {
@@ -186,7 +185,7 @@ command_save (gpointer   callback_data,
                         : file_save_list (file, mmaid, root, mmaid->charset,
                                                             mmaid->playlist))
                 && (mmaid->filekind == FILE_KIND_DB || mmaid->playlist != 2))
-        misc_mdi_set_edited (MISC_MDI (mdi), page_num, FALSE);
+        orz_mdi_set_edited (ORZ_MDI (mdi), page_num, FALSE);
     }
   g_free (root);
 }
@@ -230,7 +229,7 @@ command_save_ok (GtkWidget     *widget,
                                         (GTK_FILE_SELECTION (cmd_sv->dialog)));
   cmd_sv->root    = g_strdup (gtk_entry_get_text
                             (GTK_ENTRY (GTK_COMBO (cmd_sv->combo)->entry)));
-  cmd_sv->charset = misc_charset_get_charset (MISC_CHARSET (cmd_sv->combo1));
+  cmd_sv->charset = orz_charset_get_charset (ORZ_CHARSET (cmd_sv->combo1));
   cmd_sv->filekind = gtk_toggle_button_get_active
         (GTK_TOGGLE_BUTTON (cmd_sv->radio0)) ? FILE_KIND_DB : FILE_KIND_LIST;
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cmd_sv->radio3)))
@@ -265,15 +264,14 @@ command_save_edited (GtkWidget     *widget,
                      CommandSaveOk *cmd_sv)
 {
   gtk_widget_set_sensitive (GTK_FILE_SELECTION (cmd_sv->dialog)->ok_button,
-                                misc_charset_is_valid (MISC_CHARSET (widget)));
+                                orz_charset_is_valid (ORZ_CHARSET (widget)));
 }
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
 
 
 void
-command_saveas (gpointer   callback_data,
-                guint      callback_action,
-                GtkWidget *widget)
+command_saveas (GtkWidget *widget,
+                gpointer   user_data)
 {
   gchar *name, *path, *root = NULL, *tmp, **ary;
   gint i, page_num;
@@ -283,7 +281,7 @@ command_saveas (gpointer   callback_data,
   MmaidWindow *mmaid;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  mmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
+  mmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
   g_memset (&cmd_sv, 0 ,sizeof (CommandSaveOk));
   /* ja:共通のルートを求める */
   for (i = mm_list_length (MM_LIST (mmaid->list)) - 1; i >= 0; i--)
@@ -405,9 +403,9 @@ command_saveas (gpointer   callback_data,
     g_free (g_list_nth_data (glist, i));
   g_list_free (glist);
   /* ja:文字符号化方式 */
-  cmd_sv.combo1 = misc_charset_new ();
-  misc_charset_add_candidate (MISC_CHARSET (cmd_sv.combo1), charset_list);
-  misc_charset_set_charset (MISC_CHARSET (cmd_sv.combo1), mmaid->charset);
+  cmd_sv.combo1 = orz_charset_new ();
+  orz_charset_add_candidate (ORZ_CHARSET (cmd_sv.combo1), charset_list);
+  orz_charset_set_charset (ORZ_CHARSET (cmd_sv.combo1), mmaid->charset);
   /* ja:ラベル */
   label0 = gtk_label_new_with_mnemonic (_("_Root"));
   label1 = gtk_label_new_with_mnemonic (_("Character _Encoding"));
@@ -453,7 +451,7 @@ command_saveas (gpointer   callback_data,
   if (root)
     gtk_file_chooser_set_current_folder
                                     (GTK_FILE_CHOOSER (cmd_sv.dialog), root);
-  name = g_path_get_basename (misc_mdi_get_file (MISC_MDI (mdi), page_num));
+  name = g_path_get_basename (orz_mdi_get_file (ORZ_MDI (mdi), page_num));
   tmp = g_filename_to_utf8 (name, -1, NULL, NULL, NULL);
   gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (cmd_sv.dialog), tmp);
   g_free (tmp);
@@ -475,7 +473,7 @@ command_saveas (gpointer   callback_data,
                     (gtk_combo_box_get_model (GTK_COMBO_BOX (cmd_sv.combo0)),
                                                 &iter, 0, &cmd_sv.root, -1);
 # endif /* not GTK_CHECK_VERSION(2,6,0) */
-      cmd_sv.charset = misc_charset_get_charset (MISC_CHARSET (cmd_sv.combo1));
+      cmd_sv.charset = orz_charset_get_charset (ORZ_CHARSET (cmd_sv.combo1));
       cmd_sv.filekind = gtk_toggle_button_get_active
         (GTK_TOGGLE_BUTTON (cmd_sv.radio0)) ? FILE_KIND_DB : FILE_KIND_LIST;
       if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cmd_sv.radio3)))
@@ -509,7 +507,7 @@ command_saveas (gpointer   callback_data,
                                 G_CALLBACK (command_save_edited), &cmd_sv);
   gtk_box_pack_end (GTK_BOX (GTK_FILE_SELECTION (cmd_sv.dialog)->main_vbox),
                                                         vbox, FALSE, FALSE, 0);
-  name = g_path_get_basename (misc_mdi_get_file (MISC_MDI (mdi), page_num));
+  name = g_path_get_basename (orz_mdi_get_file (ORZ_MDI (mdi), page_num));
   tmp = root ? g_strconcat (root, name, NULL)
              : g_strconcat (save_path, G_DIR_SEPARATOR_S, name, NULL);
   gtk_file_selection_set_filename (GTK_FILE_SELECTION (cmd_sv.dialog), tmp);
@@ -548,14 +546,14 @@ command_saveas (gpointer   callback_data,
           if (cmd_sv.filekind == FILE_KIND_DB || cmd_sv.playlist != 2)
             {
               /* ja:諸設定 */
-              misc_mdi_set_created (MISC_MDI (mdi), page_num, FALSE);
-              misc_mdi_set_edited (MISC_MDI (mdi), page_num, FALSE);
-              misc_mdi_set_file (MISC_MDI (mdi), page_num, cmd_sv.file);
+              orz_mdi_set_created (ORZ_MDI (mdi), page_num, FALSE);
+              orz_mdi_set_edited (ORZ_MDI (mdi), page_num, FALSE);
+              orz_mdi_set_file (ORZ_MDI (mdi), page_num, cmd_sv.file);
             }
           mmaid->filekind = cmd_sv.filekind;
           if (cmd_sv.filekind == FILE_KIND_LIST)
             playlist = mmaid->playlist = cmd_sv.playlist;
-          misc_history_add_file (MISC_HISTORY (history), cmd_sv.file);
+          orz_history_add_file (ORZ_HISTORY (history), cmd_sv.file);
         }
       g_free (text);
     }
@@ -567,9 +565,8 @@ command_saveas (gpointer   callback_data,
 
 
 void
-command_reload (gpointer   callback_data,
-                guint      callback_action,
-                GtkWidget *widget)
+command_reload (GtkWidget *widget,
+                gpointer   user_data)
 {
   gchar *text;
   const gchar *file;
@@ -577,9 +574,9 @@ command_reload (gpointer   callback_data,
   MmaidWindow *mmaid;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  mmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
-  file = misc_mdi_get_file (MISC_MDI (mdi), page_num);
-  text = misc_mdi_get_edited (MISC_MDI (mdi), page_num) ? g_strdup_printf
+  mmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
+  file = orz_mdi_get_file (ORZ_MDI (mdi), page_num);
+  text = orz_mdi_get_edited (ORZ_MDI (mdi), page_num) ? g_strdup_printf
             (_("File %s was edited.\nRestore to existed file?"), file) : NULL;
   if (reload_dialog (mmaid, text))
     {
@@ -587,7 +584,7 @@ command_reload (gpointer   callback_data,
       mm_list_delete_all (MM_LIST (mmaid->list));
       /* ja:再読み込み */
       file_open_db (file, mmaid);
-      misc_mdi_set_edited (MISC_MDI (mdi), page_num, FALSE);
+      orz_mdi_set_edited (ORZ_MDI (mdi), page_num, FALSE);
       charlist_renewal_all (mmaid->charset);
       set_menu_bar (mmaid);
     }
@@ -603,16 +600,15 @@ command_dialog_abort (GtkWidget *widget,
 
 
 void
-command_export (gpointer   callback_data,
-                guint      callback_action,
-                GtkWidget *widget)
+command_export (GtkWidget *widget,
+                gpointer   user_data)
 {
   gint i, count;
   GtkWidget *dialog;
   ExportInfo *expinfo;
   MmaidWindow *mmaid;
 
-  mmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+  mmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   expinfo = export_dialog (mmaid->charset);
   if (!expinfo)
     return;
@@ -737,9 +733,8 @@ command_export (gpointer   callback_data,
 
 
 void
-command_exit (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_exit (GtkWidget *widget,
+              gpointer   user_data)
 {
   GdkEvent event;
 
@@ -751,54 +746,51 @@ command_exit (gpointer   callback_data,
 
 
 void
-command_up (gpointer   callback_data,
-            guint      callback_action,
-            GtkWidget *widget)
+command_up (GtkWidget *widget,
+            gpointer   user_data)
 {
   gint i, count, page_num;
   MmaidWindow *mmaid;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  mmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
+  mmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
   count = mm_list_length (MM_LIST (mmaid->list));
   for (i = 1; i < count; i++)
     if (!mm_list_is_selected (MM_LIST (mmaid->list), i - 1)
                             && mm_list_is_selected (MM_LIST (mmaid->list), i))
       mm_list_swap (MM_LIST (mmaid->list), i - 1, i);
-  misc_mdi_set_edited (MISC_MDI (mdi), page_num, TRUE);
+  orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
 }
 
 
 void
-command_down (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_down (GtkWidget *widget,
+              gpointer   user_data)
 {
   gint i, page_num;
   MmaidWindow *mmaid;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  mmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
+  mmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
   for (i = mm_list_length (MM_LIST (mmaid->list)) - 2; i >= 0 ; i--)
     if (mm_list_is_selected (MM_LIST (mmaid->list), i)
                         && !mm_list_is_selected (MM_LIST (mmaid->list), i + 1))
       mm_list_swap (MM_LIST (mmaid->list), i, i + 1);
-  misc_mdi_set_edited (MISC_MDI (mdi), page_num, TRUE);
+  orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
 }
 
 
 void
-command_root (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_root (GtkWidget *widget,
+              gpointer   user_data)
 {
-  root_dialog ((MmaidWindow *)misc_mdi_get_data (MISC_MDI (mdi), -1));
+  root_dialog ((MmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), -1));
 }
 
 
 static void
 command_dialog_ok (GtkWidget *widget,
-                    GtkWidget *dialog)
+                   GtkWidget *dialog)
 {
   gboolean edited = FALSE;
   gint i, count;
@@ -840,23 +832,22 @@ command_dialog_ok (GtkWidget *widget,
         }
     }
   if (edited)
-    misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid), TRUE);
+    orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid), TRUE);
   gtk_widget_destroy (dialog);
 }
 
 
 void
-command_refresh (gpointer   callback_data,
-                 guint      callback_action,
-                 GtkWidget *widget)
+command_refresh (GtkWidget *widget,
+                 gpointer   user_data)
 {
   gboolean selected = FALSE;
   gint i, count;
   GtkWidget *dialog;
   MmaidWindow *mmaid;
 
-  mmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+  mmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   /* ja:選択の数を数える */
   count = mm_list_length (MM_LIST (mmaid->list));
   for (i = 0; i < count; i++)
@@ -947,20 +938,18 @@ command_refresh (gpointer   callback_data,
 
 
 void
-command_add (gpointer   callback_data,
-             guint      callback_action,
-             GtkWidget *widget)
+command_add (GtkWidget *widget,
+             gpointer   user_data)
 {
-  add_dialog ((MmaidWindow *)misc_mdi_get_data (MISC_MDI (mdi), -1));
+  add_dialog ((MmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), -1));
 }
 
 
 void
-command_edit (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_edit (GtkWidget *widget,
+              gpointer   user_data)
 {
-  edit_dialog ((MmaidWindow *)misc_mdi_get_data (MISC_MDI (mdi), -1));
+  edit_dialog ((MmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), -1));
 }
 
 
@@ -1077,9 +1066,8 @@ command_search_recursive (const gchar *path,
 
 
 void
-command_search (gpointer   callback_data,
-                guint      callback_action,
-                GtkWidget *widget)
+command_search (GtkWidget *widget,
+                gpointer   user_data)
 {
   gchar *path, *tmp;
   const gchar *file;
@@ -1088,8 +1076,8 @@ command_search (gpointer   callback_data,
   MmaidWindow *mmaid;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  mmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
-  file = misc_mdi_get_data (MISC_MDI (mdi), page_num);
+  mmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
+  file = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
   path = g_path_is_absolute (file) ? g_path_get_dirname (file)
        : open_path ? g_strdup (open_path)
        : save_path ? g_strdup (save_path)
@@ -1187,19 +1175,17 @@ command_search (gpointer   callback_data,
 
 
 void
-command_cut (gpointer   callback_data,
-             guint      callback_action,
-             GtkWidget *widget)
+command_cut (GtkWidget *widget,
+             gpointer   user_data)
 {
-  command_copy   (callback_data, callback_action, widget);
-  command_delete (callback_data, callback_action, widget);
+  command_copy (widget, user_data);
+  command_delete (widget, user_data);
 }
 
 
 void
-command_copy (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_copy (GtkWidget *widget,
+              gpointer   user_data)
 {
 #ifndef G_OS_WIN32
   if (gtk_selection_owner_set (window, GDK_SELECTION_CLIPBOARD,
@@ -1209,7 +1195,7 @@ command_copy (gpointer   callback_data,
       gint i, count;
       MmaidWindow *mmaid;
 
-      mmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+      mmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
       g_free (clipboard_id3tag);
       clipboard_id3tag = NULL;
       count = mm_list_length (MM_LIST (mmaid->list));
@@ -1284,9 +1270,8 @@ command_copy (gpointer   callback_data,
 
 
 void
-command_paste (gpointer   callback_data,
-               guint      callback_action,
-               GtkWidget *widget)
+command_paste (GtkWidget *widget,
+               gpointer   user_data)
 {
   /* ja:Windowsのセレクションの実装があやしいので暫定的処理 */
 #ifdef G_OS_WIN32
@@ -1325,31 +1310,29 @@ command_paste (gpointer   callback_data,
 
 
 void
-command_delete (gpointer   callback_data,
-                guint      callback_action,
-                GtkWidget *widget)
+command_delete (GtkWidget *widget,
+                gpointer   user_data)
 {
   gint i, page_num;
   MmaidWindow *mmaid;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  mmaid = misc_mdi_get_data (MISC_MDI (mdi), page_num);
+  mmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
   for (i = mm_list_length (MM_LIST (mmaid->list)) - 1; i >= 0 ; i--)
     if (mm_list_is_selected (MM_LIST (mmaid->list), i))
       mm_list_delete (MM_LIST (mmaid->list), i);
-  misc_mdi_set_edited (MISC_MDI (mdi), page_num, TRUE);
+  orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
 }
 
 
 void
-command_all (gpointer   callback_data,
-             guint      callback_action,
-             GtkWidget *widget)
+command_all (GtkWidget *widget,
+             gpointer   user_data)
 {
   gint i;
   MmaidWindow *mmaid;
 
-  mmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+  mmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   for (i = mm_list_length (MM_LIST (mmaid->list)) - 1; i >= 0 ; i--)
     if (!mm_list_is_selected (MM_LIST (mmaid->list), i))
       break;
@@ -1364,12 +1347,12 @@ static void
 command_conf_ok (GtkWidget *widget,
                  GtkWidget *dialog)
 {
-  misc_history_set_num (MISC_HISTORY (history),
-                                misc_conf_get_history (MISC_CONF (dialog)));
-  newfile = misc_conf_get_newfile (MISC_CONF (dialog));
-  second = misc_conf_get_second (MISC_CONF (dialog));
-  misc_conf_get_size (MISC_CONF (dialog), &def_width, &def_height);
-  n_pos = misc_conf_get_tab (MISC_CONF (dialog));
+  orz_history_set_num (ORZ_HISTORY (history),
+                                    orz_conf_get_history (ORZ_CONF (dialog)));
+  newfile = orz_conf_get_newfile (ORZ_CONF (dialog));
+  second = orz_conf_get_second (ORZ_CONF (dialog));
+  orz_conf_get_size (ORZ_CONF (dialog), &def_width, &def_height);
+  n_pos = orz_conf_get_tab (ORZ_CONF (dialog));
   gtk_widget_destroy (dialog);
   /* ja:ノートの位置 */
   gtk_notebook_set_tab_pos (GTK_NOTEBOOK (mdi), n_pos);
@@ -1377,57 +1360,63 @@ command_conf_ok (GtkWidget *widget,
 
 
 void
-command_conf (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_conf (GtkWidget *widget,
+              gpointer   user_data)
 {
   GtkWidget *dialog;
 
-  dialog = misc_conf_new ();
+  dialog = orz_conf_new ();
   g_signal_connect (G_OBJECT (dialog), "destroy",
                                             G_CALLBACK (gtk_main_quit), NULL);
-  g_signal_connect (G_OBJECT (MISC_CONF (dialog)->ok_button),
+  g_signal_connect (G_OBJECT (ORZ_CONF (dialog)->ok_button),
                             "clicked", G_CALLBACK (command_conf_ok), dialog);
-  g_signal_connect_swapped (G_OBJECT (MISC_CONF (dialog)->cancel_button),
+  g_signal_connect_swapped (G_OBJECT (ORZ_CONF (dialog)->cancel_button),
             "clicked", G_CALLBACK (gtk_widget_destroy), GTK_OBJECT (dialog));
-  misc_conf_set_history (MISC_CONF(dialog),
-                                misc_history_get_num (MISC_HISTORY (history)));
-  misc_conf_set_newfile (MISC_CONF(dialog), newfile);
-  misc_conf_set_second (MISC_CONF(dialog), second);
-  misc_conf_set_size (MISC_CONF(dialog), def_width, def_height);
-  misc_conf_set_tab (MISC_CONF(dialog), n_pos);
+  orz_conf_set_history (ORZ_CONF (dialog),
+                                orz_history_get_num (ORZ_HISTORY (history)));
+  orz_conf_set_newfile (ORZ_CONF (dialog), newfile);
+  orz_conf_set_second (ORZ_CONF (dialog), second);
+  orz_conf_set_size (ORZ_CONF (dialog), def_width, def_height);
+  orz_conf_set_tab (ORZ_CONF (dialog), n_pos);
   gtk_widget_show (dialog);
   gtk_grab_add (dialog);
   gtk_main ();
 }
 
 
+void
+command_genre (GtkWidget *widget,
+               gpointer   user_data)
+{
+  genre_dialog ();
+}
+
+
 static void
 command_charset_ok (GtkWidget *widget,
                     GtkWidget *dialog)
 {
   g_free (charset_list);
-  charset_list = misc_charlist_get_charlist (MISC_CHARLIST (dialog));
+  charset_list = orz_charlist_get_charlist (ORZ_CHARLIST (dialog));
   charlist_renewal_all (charset_list);
   gtk_widget_destroy (dialog);
 }
 
 
 void
-command_charset (gpointer   callback_data,
-                 guint      callback_action,
-                 GtkWidget *widget)
+command_charset (GtkWidget *widget,
+                 gpointer   user_data)
 {
   GtkWidget *dialog;
 
-  dialog = misc_charlist_new ();
+  dialog = orz_charlist_new ();
   g_signal_connect (G_OBJECT (dialog), "destroy",
                                             G_CALLBACK (gtk_main_quit), NULL);
-  g_signal_connect (G_OBJECT (MISC_CHARLIST (dialog)->ok_button),
+  g_signal_connect (G_OBJECT (ORZ_CHARLIST (dialog)->ok_button),
                         "clicked", G_CALLBACK (command_charset_ok), dialog);
-  g_signal_connect_swapped (G_OBJECT (MISC_CHARLIST (dialog)->cancel_button),
+  g_signal_connect_swapped (G_OBJECT (ORZ_CHARLIST (dialog)->cancel_button),
             "clicked", G_CALLBACK (gtk_widget_destroy), GTK_OBJECT (dialog));
-  misc_charlist_set_charlist (MISC_CHARLIST (dialog), charset_list);
+  orz_charlist_set_charlist (ORZ_CHARLIST (dialog), charset_list);
   gtk_widget_show (dialog);
   gtk_grab_add (dialog);
   gtk_main ();
@@ -1435,9 +1424,24 @@ command_charset (gpointer   callback_data,
 
 
 void
-command_play (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_process (GtkWidget *widget,
+                 gpointer   user_data)
+{
+  process_dialog ();
+}
+
+
+void
+command_version (GtkWidget *widget,
+                 gpointer   user_data)
+{
+  version_dialog ();
+}
+
+
+void
+command_play (GtkWidget *widget,
+              gpointer   user_data)
 {
   gchar *cmd;
 
@@ -1447,7 +1451,7 @@ command_play (gpointer   callback_data,
       gint n;
       MmaidWindow *mmaid;
 
-      mmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+      mmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
       mm_list_get_cursor (MM_LIST (mmaid->list), &n, NULL);
       if (n >= 0)
         {
@@ -1475,9 +1479,8 @@ command_play (gpointer   callback_data,
 
 
 void
-command_stop (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_stop (GtkWidget *widget,
+              gpointer   user_data)
 {
   gchar *cmd;
 
