@@ -173,4 +173,4 @@ command_stop (GtkWidget *widget,
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __COMMAND_H__ */
