@@ -39,7 +39,7 @@
 #define METAINFO_ALBUM  3
 #define METAINFO_GENRE  4
 
-typedef struct MetaInfo_Tag
+typedef struct _MetaInfo
 {
   gsize len[5];
   gchar *str[5];
