@@ -78,4 +78,4 @@ copy_id3tag (const ID3Tag *id3tag);
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __GENERAL_H__ */
