@@ -39,14 +39,14 @@ extern "C" {
 #define MENUFILE 10
 
 
-typedef struct MmaidWindow_Tag
+typedef struct _MmaidWindow
 {
   gchar *charset;               /* ja:キャラクターセット */
   guint filekind;               /* ja:ファイルの種類 */
   gint playlist;                /* ja:プレイリスト(0:相対,1:絶対,2:名前) */
   GtkWidget *list;              /* ja:描画領域 */
 } MmaidWindow;
-typedef struct ID3Tag_Tag
+typedef struct _ID3Tag
 {
   gchar *file;
   gchar *title;
@@ -98,4 +98,4 @@ extern MiscCreateMenuEntry popup_entries[];
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __MMAID_H__ */
