@@ -21,7 +21,7 @@
 #include "mm_list.h"
 #include "root.h"
 #include "misc/fileio.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -181,8 +181,8 @@ root_dialog_clicked_ok (GtkWidget   *widget,
   g_free (find);
 #endif /* GTK_CHECK_VERSION(2,4,0) */
   g_free (replace);
-  misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), mmaid), TRUE);
+  orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), mmaid), TRUE);
   gtk_widget_destroy (dialog);
 }
 
