@@ -113,4 +113,4 @@ signal_delete (GtkWidget *widget,
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __SIGMAIN_H__ */
