@@ -37,4 +37,4 @@ extern MiscCreateToolbarEntry toolbar_entries[];
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __TOOLBAR_H__ */
